;------------------------------------------------------------------------------
;
; Title:			ds30 loader for dsPIC33
;
; File description:	user settings and configuration bits
;
; Copyright: 		Copyright  09-10, Mikael Gustafsson
;
; Webpage: 			http://mrmackey.no-ip.org/elektronik/ds30loader/
;
; History:			1.1.0 New setting: auto baudrate detection
;						  New setting: bootloader protection
;						  New setting: high baud rates
;					1.0.4 New setting: goto protection
;					1.0.3 Added tx enable setting
;					1.0.2 -
;					1.0.1 -
;					1.0.0 -
;					0.9.4 -
;					0.9.3 Removed 1-way pps config
;					0.9.2 Removed PLL settings
;						  Adde config to incativate 1-way pps
;					0.9.1 Only one clock option in this file
;					0.9.0 First version of this file
;                                                                             
;------------------------------------------------------------------------------

;-----------------------------------------------------------------------------
;    This file is part of ds30 Loader.
;
;    ds30 Loader is free software: you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation.
;
;    ds30 Loader is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with ds30 Loader. If not, see <http://www.gnu.org/licenses/>.
;------------------------------------------------------------------------------ 


;------------------------------------------------------------------------------
; Device
;------------------------------------------------------------------------------
        .equ 		__33FJ64GP802, 	1		;xxx device


;------------------------------------------------------------------------------
; Includes
;------------------------------------------------------------------------------
        .include	"devices.inc"


;------------------------------------------------------------------------------
; User preferences
;------------------------------------------------------------------------------
		.equ 	FCY, 		8000000				;xxx speed of internal cycle clock[Hz], used to calculate uart brg and delay
		.equ 	BAUDRATE, 	125000				;xxx baudrate
		.equ	BLTIME,		4000				;xxx time in ms before bootloader loads the user application
        
        .equ    USE_UART1,	1					;xxx uncomment to use uart1
        ;.equ	USE_UART2,	1					;xxx uncomment to use uart2        
        ;.equ	USE_ABAUD,	1					;xxx uncomment to use auto baud rate detection, READ ERRATA FIRST
        ;.equ	USE_BRGH,	1					;xxx uncomment to use high baud rates, READ ERRATA FIRST
		
		;.equ	USE_TXENABLE,	1				;xxx uncomment to use a tx enable pin		
		.ifdef USE_TXENABLE
			.equ	TRISR_TXE,	TRISA			;xxx tris register containing tx enable
			.equ 	LATR_TXE,	LATA			;xxx port register containing tx enable
			.equ	TRISB_TXE,	TRISA1			;xxx tris bit for tx enable
			.equ	LATB_TXE,	RA1				;xxx port bit for tx enable
		.endif
		
		
;------------------------------------------------------------------------------
; Advanced settings
;------------------------------------------------------------------------------
		.equ	PROT_GOTO,		1				;xxx protect goto at 0x00
		.equ	PROT_BL,		1				;xxx protect bootloader
				

;------------------------------------------------------------------------------
; Configuration bits, these macros can be found at the end of the inc-files located in 
; c:\Program files\Microchip\MPLAB ASM30 Suite\Support\dsPIC33F\inc
;
; These can also be set in MPLAB IDE instead, they are found in Configure->Configuration bits...
;------------------------------------------------------------------------------
		;config 	__FBS, 		RBS_NO_RAM & BSS_NO_FLASH & BWRP_WRPROTECT_OFF	;xxx boot segment
		;config 	__FSS, 		RSS_NO_RAM & SSS_NO_FLASH & SWRP_WRPROTECT_OFF	;xxx secure segment
		;config 	__FGS,		GSS_OFF & GCP_OFF & GWRP_OFF					;xxx general segment
;		config 	__FOSCSEL, 	FNOSC_FRC & IESO_OFF 							;xxx oscillator mode
;		config 	__FOSC, 	FCKSM_CSDCMD & OSCIOFNC_ON & POSCMD_XT			;xxx clock switching/clock monitor, osc2 & oscillator selection
		;config	__FWDT,		FWDTEN_OFF & WINDIS_OFF							;xxx watchdog
		;config	__FPOR,		FPWRT_PWR1										;xxx pwm, power-on reset
		;config	__FICD,		JTAGEN_OFF & ICS_PGD1

; 4MIPS
;  config 	__FGS, GCP_OFF & GSS_OFF & GWRP_OFF 
;   config     __FOSCSEL, FNOSC_PRI & IESO_OFF & 0xFFFF 
;   config     __FOSC, FCKSM_CSDCMD & OSCIOFNC_OFF & POSCMD_XT
;   config     __FPOR, FPWRT_PWR1 
;   config     __FWDT, FWDTEN_OFF 
;   config     __FICD, JTAGEN_OFF & ICS_PGD1 

;40Mips
   config 	__FGS, GCP_OFF & GSS_OFF & GWRP_OFF 
   config     __FOSCSEL, FNOSC_PRIPLL & IESO_OFF & 0xFFFF ;FNOSC_PRIPLL
   config     __FOSC, FCKSM_CSECMD & OSCIOFNC_OFF & POSCMD_XT
   config     __FPOR, FPWRT_PWR1 
   config     __FWDT, FWDTEN_OFF 
   config     __FICD, JTAGEN_OFF & ICS_PGD1 

